ContainerExt

Trait ContainerExt 

pub trait ContainerExt
where Self: LayoutExt,
{ // Provided methods fn padding(self, padding: impl Into<Gaps>) -> Self { ... } fn min_width(self, minimum_width: impl Into<Size>) -> Self { ... } fn min_height(self, minimum_height: impl Into<Size>) -> Self { ... } fn max_width(self, maximum_width: impl Into<Size>) -> Self { ... } fn max_height(self, maximum_height: impl Into<Size>) -> Self { ... } fn visible_width(self, visible_width: impl Into<VisibleSize>) -> Self { ... } fn visible_height(self, visible_height: impl Into<VisibleSize>) -> Self { ... } }
Methods controlling an element’s spacing and size constraints.

Provided Methods

fn padding(self, padding: impl Into<Gaps>) -> Self

Set the inner spacing between the element’s edges and its content. See Gaps.

fn min_width(self, minimum_width: impl Into<Size>) -> Self

Set the minimum width the element can shrink to. See Size.

fn min_height(self, minimum_height: impl Into<Size>) -> Self

Set the minimum height the element can shrink to. See Size.

fn max_width(self, maximum_width: impl Into<Size>) -> Self

Set the maximum width the element can grow to. See Size.

fn max_height(self, maximum_height: impl Into<Size>) -> Self

Set the maximum height the element can grow to. See Size.

fn visible_width(self, visible_width: impl Into<VisibleSize>) -> Self

Set how much of the measured width is actually used in layout. See VisibleSize.

fn visible_height(self, visible_height: impl Into<VisibleSize>) -> Self

Set how much of the measured height is actually used in layout. See VisibleSize.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors