ContainerPositionExt

Trait ContainerPositionExt 

pub trait ContainerPositionExt
where Self: LayoutExt,
{ // Provided methods fn position(self, position: impl Into<Position>) -> Self { ... } fn margin(self, margin: impl Into<Gaps>) -> Self { ... } }
Methods for setting how an element is placed relative to its parent or the window.

Provided Methods

fn position(self, position: impl Into<Position>) -> Self

Set how the element is placed relative to its parent or the window. See Position.

fn margin(self, margin: impl Into<Gaps>) -> Self

Set the outer spacing between the element’s edges and its surroundings. See Gaps.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors