Module rect
freya_
core
0.4.0
Module rect
Module Items
Structs
Functions
In freya_
core::
elements
freya_core
::
elements
Module
rect
rect()
acts as a generic container to contain other elements inside, like a box.
Structs

Rect
Rect
Element
Functions

rect
rect()
acts as a generic container to contain other elements inside, like a box.